@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -27,7 +27,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <mate-panel-applet-mateconf.h>
+#include <mate-panel-applet.h>
 #include <X11/XKBlib.h>
 
 #define XK_MISCELLANY
@@ -127,7 +127,7 @@ static void about_cb(GtkAction* action, AccessxStatusApplet* sapplet)
 
 	const gchar* documenters[] = {
 		"Bill Haneman <bill.haneman@sun.com>",
-		"Sun MATE Documentation Team <gdocteam@sun.com>",
+		"Sun GNOME Documentation Team <gdocteam@sun.com>",
 		NULL
 	};
 
