@@ -162,10 +162,10 @@ add_palette_cb (GtkDialog *dialog, int response_id, charpick_data *curr_data)
 		curr_data->charlist = curr_data->chartable->data;
 		build_table (curr_data);
 
-		if (key_writable (MATE_PANEL_APPLET (curr_data->applet), "current_list"))
-			mate_panel_applet_mateconf_set_string (MATE_PANEL_APPLET (curr_data->applet),
-						      "current_list", 
-					  	       curr_data->charlist, NULL);
+		if (g_settings_is_writable (curr_data->settings, "current-list"))
+			g_settings_set_string (curr_data->settings,
+						      "current-list", 
+					  	       curr_data->charlist);
 	}
 
 	save_chartable (curr_data);
@@ -226,8 +226,8 @@ edit_palette_cb (GtkDialog *dialog, int response_id, charpick_data *curr_data)
 		curr_data->charlist = new;
 		build_table (curr_data);
 
-		if (key_writable (MATE_PANEL_APPLET (curr_data->applet), "current_list"))
-			mate_panel_applet_mateconf_set_string (MATE_PANEL_APPLET (curr_data->applet), "current_list", curr_data->charlist, NULL);
+		if (g_settings_is_writable (curr_data->settings, "current-list"))
+			g_settings_set_string (curr_data->settings, "current-list", curr_data->charlist);
 	}
 	
 	g_free (charlist);
@@ -315,8 +315,8 @@ delete_palette (GtkButton *button, charpick_data *curr_data)
 	if (g_ascii_strcasecmp (curr_data->charlist, charlist) == 0) {
 		curr_data->charlist = curr_data->chartable != NULL ? 
 				      curr_data->chartable->data : "";
-		if (key_writable (MATE_PANEL_APPLET (curr_data->applet), "current_list"))
-			mate_panel_applet_mateconf_set_string (MATE_PANEL_APPLET (curr_data->applet), "current_list", curr_data->charlist, NULL);
+		if (g_settings_is_writable (curr_data->settings, "current-list"))
+			g_settings_set_string (curr_data->settings, "current-list", curr_data->charlist);
 	}
 	g_free (charlist);
 	
@@ -489,7 +489,7 @@ static void default_chars_frame_create(charpick_data *curr_data)
   set_access_namedesc (button, _("Delete button"),
 				         _("Click to delete the selected palette"));
 
-  if ( ! key_writable (MATE_PANEL_APPLET (curr_data->applet), "chartable"))
+  if ( ! g_settings_is_writable (curr_data->settings, "chartable"))
 	  gtk_widget_set_sensitive (vbox3, FALSE);
    
   return;
