@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Author:
  *   James Henstridge <jamesh@canonical.com>
@@ -175,9 +175,6 @@ applet_factory (MatePanelApplet *applet,
 	gtk_window_set_default_icon_name ("media-floppy");
 
 	mate_panel_applet_set_flags (applet, MATE_PANEL_APPLET_EXPAND_MINOR);
-	mate_panel_applet_add_preferences (applet,
-				      "/schemas/apps/drivemount-applet/prefs",
-				      NULL);
 	mate_panel_applet_set_background_widget (applet, GTK_WIDGET (applet));
 
 	drive_list = drive_list_new ();
