@@ -3,16 +3,21 @@ from os.path import join
 from gettext import gettext as _
 from mate_invest.defs import VERSION
 import mate_invest
-import gtk, gtk.gdk
+
+import gi
+gi.require_version("Gtk", "2.0")
+from gi.repository import Gtk
+from gi.repository import Gdk
+from gi.repository import GdkPixbuf
 
 invest_logo = None
 try:
-	invest_logo = gtk.gdk.pixbuf_new_from_file_at_size(join(mate_invest.ART_DATA_DIR, "invest_neutral.svg"), 96, 96)
+	invest_logo = GdkPixbuf.Pixbuf.new_from_file_at_size(join(mate_invest.ART_DATA_DIR, "invest_neutral.svg"), 96, 96)
 except Exception, msg:
 	pass
 	
 def show_about():
-	about = gtk.AboutDialog()
+	about = Gtk.AboutDialog()
 	infos = {
 		"program-name" : _("Invest"),
 		"logo" : invest_logo,
@@ -21,7 +26,7 @@ def show_about():
 		"copyright" : "Copyright © 2004-2005 Raphael Slinckx.\nCopyright © 2009-2010 Enrico Minack."
 	}
 
-	about.set_authors(["Raphael Slinckx <raphael@slinckx.net>", "Enrico Minack <enrico-minack@gmx.de>"])
+#	about.set_authors("Raphael Slinckx <raphael@slinckx.net>\nEnrico Minack <enrico-minack@gmx.de>")
 #	about.set_artists([])
 #	about.set_documenters([])
 	
