@@ -21,15 +21,14 @@
 #include <arpa/nameser.h>
 #include <resolv.h>
 
-#include <mateconf/mateconf-client.h>
+#include <gio/gio.h>
 #include <mate-panel-applet.h>
-#include <mate-panel-applet-mateconf.h>
+#include <mate-panel-applet-gsettings.h>
 
 #include <gdk/gdkkeysyms.h>
 
-#ifdef HAVE_LIBMATENOTIFY
-#include <libmatenotify/notify.h>
-#include <libmatenotify/notification.h>
+#ifdef HAVE_LIBNOTIFY
+#include <libnotify/notify.h>
 #endif
 
 #define MATEWEATHER_I_KNOW_THIS_IS_UNSTABLE
@@ -294,8 +293,9 @@ applet_destroy (GtkWidget *widget, MateWeatherApplet *gw_applet)
        gw_applet->suncalc_timeout_tag = 0;
     }
 	
-    if (gw_applet->mateconf) {
-       mateweather_mateconf_free (gw_applet->mateconf);
+    if (gw_applet->settings) {
+       g_object_unref (gw_applet->settings);
+       gw_applet->settings = NULL;
     }
 
     weather_info_abort (gw_applet->mateweather_info);
@@ -312,6 +312,7 @@ void mateweather_applet_create (MateWeatherApplet *gw_applet)
     AtkObject      *atk_obj;
 
     gw_applet->mateweather_pref.location = NULL;
+    gw_applet->mateweather_pref.show_notifications = FALSE;
     gw_applet->mateweather_pref.update_interval = 1800;
     gw_applet->mateweather_pref.update_enabled = TRUE;
     gw_applet->mateweather_pref.detailed = FALSE;
@@ -392,9 +393,8 @@ static void
 update_finish (WeatherInfo *info, gpointer data)
 {
     static int gw_fault_counter = 0;
-#ifdef HAVE_LIBMATENOTIFY
+#ifdef HAVE_LIBNOTIFY
     char *message, *detail;
-    MateConfClient *conf;
 #endif
     char *s;
     MateWeatherApplet *gw_applet = (MateWeatherApplet *)data;
@@ -442,10 +442,9 @@ update_finish (WeatherInfo *info, gpointer data)
 	    /* update applet */
 	    place_widgets(gw_applet);
 
-#ifdef HAVE_LIBMATENOTIFY
-	    if (mate_panel_applet_mateconf_get_bool (gw_applet->applet,
-				    "show_notifications", NULL))
-	    {
+#ifdef HAVE_LIBNOTIFY
+        if (gw_applet->mateweather_pref.show_notifications)
+        {
 		    NotifyNotification *n;
 	            
 		    /* Show notifications if possible */
@@ -471,8 +470,7 @@ update_finish (WeatherInfo *info, gpointer data)
 			 if (icon == NULL)
 				 icon = "stock-unknown";
 	           	 
-			 n = notify_notification_new (message, detail, icon,
-					 gw_applet->container);
+			 n = notify_notification_new (message, detail, icon);
 	
 		   	 notify_notification_show (n, &error);
 			 if (error)
@@ -484,7 +482,7 @@ update_finish (WeatherInfo *info, gpointer data)
 		   	 g_free (message);
 		   	 g_free (detail);
 		    }
-	    }
+        }
 #endif
     }
     else
