@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 from gettext import gettext as _
 from gettext import ngettext
@@ -128,7 +128,9 @@ class TimerApplet(object):
         
         self._status_button.set_relief(gtk.RELIEF_NONE)
         self._status_button.set_icon(config.ICON_PATH);
-        
+       
+        self._applet.set_tooltip_text(_("Timer Applet"))
+
         self._connect_signals()
         self._update_status_button()
         self._update_popup_menu()
